@@ -2,10 +2,13 @@ import binascii
 import base64
 import OpenSSL.crypto
 import signal
+import os
+import sys
 from typing import NamedTuple, Iterator, Optional, List
 from enum import Enum
 from OpenSSL.crypto import X509, FILETYPE_PEM
 from pyshark import FileCapture, LiveCapture
+from pyshark.capture.pipe_capture import PipeCapture
 from pyshark.packet.packet import Packet
 
 
@@ -91,7 +94,9 @@ class TLSHandshakeSniffer():
 
         try:
             tls_field = 'tls' if 'tls' in packet else 'ssl'
-            handshake_type = TLSHandshakeType(int(packet[tls_field].handshake_type))
+            handshake_type = TLSHandshakeType(
+                int(packet[tls_field].handshake_type)
+            )
 
             if sniff_sni and 'handshake_extensions_server_name' in packet[tls_field].field_names and packet[tls_field].handshake_extensions_server_name != '':
                 sni = packet[tls_field].handshake_extensions_server_name.lower()
@@ -101,7 +106,9 @@ class TLSHandshakeSniffer():
 
             # Hopefully the SAN section will also be accessible with pyshark in future
             if sniff_san and 'handshake_certificate' in packet[tls_field].field_names:
-                cert = cls._parse_certificate(packet[tls_field].handshake_certificate)
+                cert = cls._parse_certificate(
+                    packet[tls_field].handshake_certificate
+                )
                 if cert is not None:
                     san = cls._extract_certificate_san(cert)
 
@@ -135,7 +142,9 @@ class TLSHandshakeSniffer():
 
     def listen(self, sniff_sni=False, sniff_cn=False, sniff_san=False, packet_count: int = None, debug: bool = False) -> Iterator[TLSHandshakeMessage]:
         # Workaround for pyshark, because SIGINT handling does not work properly
-        signal.signal(signal.SIGINT, lambda *args: signal.raise_signal(signal.SIGKILL))
+        original_sigint_handler = signal.getsignal(signal.SIGINT)
+        if original_sigint_handler == signal.default_int_handler:
+            signal.signal(signal.SIGINT, lambda *args: os._exit(0))
 
         try:
             # Currently only IPv4 is supported for BPF tcp data access. Manpage says: "this will be fixed in the future" for IPv6.
@@ -153,9 +162,17 @@ class TLSHandshakeSniffer():
                 packet_count = None
 
             if self.input_file is not None:
-                packet_iterator = iter(FileCapture(input_file=self.input_file, display_filter=display_filter, keep_packets=False, debug=debug))
+                packet_iterator = FileCapture(
+                    input_file=self.input_file, display_filter=display_filter, keep_packets=False, debug=debug
+                )
+            elif not sys.stdin.isatty():
+                packet_iterator = PipeCapture(
+                    pipe=sys.stdin.buffer, display_filter=display_filter, debug=debug
+                )
             else:
-                capture = LiveCapture(interface=self.interface, bpf_filter=bpf_filter, display_filter=display_filter, debug=debug)
+                capture = LiveCapture(
+                    interface=self.interface, bpf_filter=bpf_filter, display_filter=display_filter, debug=debug
+                )
                 packet_iterator = capture.sniff_continuously()
 
             if not (sniff_sni or sniff_cn or sniff_san):
@@ -164,7 +181,9 @@ class TLSHandshakeSniffer():
                 sniff_san = True
 
             for packet in packet_iterator:
-                handshake_message = self._get_handshake_message(packet, sniff_sni=sniff_sni, sniff_cn=sniff_cn, sniff_san=sniff_san)
+                handshake_message = self._get_handshake_message(
+                    packet, sniff_sni=sniff_sni, sniff_cn=sniff_cn, sniff_san=sniff_san
+                )
 
                 if handshake_message is not None:
                     yield handshake_message
@@ -175,6 +194,9 @@ class TLSHandshakeSniffer():
                             break
 
         except Exception:
-            raise
-        
-        return
\ No newline at end of file
+            pass
+
+        # Restore original SIGINT handler
+        signal.signal(signal.SIGINT, original_sigint_handler)
+
+        return
